import requests
import json

class Orchestrator:
    def get_authentication_key(self,source_url,tenancy_name,user_name,password):
        url = source_url+"/api/Account/Authenticate"
        data = {
            "tenancyName": tenancy_name,
            "usernameOrEmailAddress": user_name,
            "password": password
            }
        responce = requests.post(url,data)
        if(responce.status_code == 200):
            responce_json = responce.json()
            return responce_json
        else:
            return responce.status_code

    def get_api_call(self,url,key,file_case = False):
        head = {
            "Content-Type" : "application/json",
            "Authorization" : "Bearer " + key
        }
        responce = requests.get(url,headers=head)
        
        if(responce.status_code == 200):
            if file_case == False:
                return responce.json()
            elif file_case == True:
                return responce
        else:
            return responce.status_code

    def post_api_call(self,url,key,data = None):
        head = {
            "Content-Type" : "application/json",
            "Authorization" : "Bearer " + key
        }
        responce = requests.post(url,headers=head,data=json.dumps(data))
        
        if(responce.status_code == 200):
            return responce.json()
        else:
            return responce.status_code


import setuptools

def readme():
    with open('README.md') as f:
        README = f.read()
    return README

# specify requirements of your package here 
REQUIREMENTS = ['requests','json'] 

# some more details 
CLASSIFIERS = [ 
	'Development Status :: 1 - Planning', 
	'Intended Audience :: Developers', 
	'Topic :: Software Development :: Libraries', 
	'License :: OSI Approved :: MIT License', 
    'Programming Language :: Python :: 2.7', 
	'Programming Language :: Python :: 3', 
    ] 

# calling the setup function 
setuptools.setup(name='A5Orchestrator', 
	version='1.0.5', 
	description='This module helps to intigrate Orchestrator with python scripts ', 
	long_description='This module helps to intigrate Orchestrator with python scripts ', 
	long_description_content_type="text/markdown",
	url='https://github.com/akvdkharnath/A5Orchestrator.git', 
	author='Harnath Atmakuri', 
	author_email='akvdkharnath@gmail.com', 
	license='MIT', 
	packages=['A5Orchestrator'], 
	include_package_data=True,
	classifiers=CLASSIFIERS, 
	install_requires=REQUIREMENTS,
	python_requires = '>=3.0',
	) 
